#[non_exhaustive]pub enum WorktreeStatus {
Idle,
Indexing,
Ready,
}Expand description
Runtime status of a managed worktree.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Idle
The worktree is registered but not currently being indexed.
Indexing
An indexing pipeline is running for this worktree.
Ready
Indexing has completed and the worktree is ready for queries.